# Core library for fundamental Ceonstock data types.
Fundamental data structures which will be used cross-context.
Minimalistic. Only includes type (enum) and class definitions.

Does not include helpers or metadata, such things should be built separately
within the context in which they are being used.
